# -*- coding: utf-8 -*-
"""
colors.py
=========

A set of colors and color maps as provided by python package `palettable` (https://jiffyclub.github.io/palettable).

"""

import numpy as np

from palettable.colorbrewer.qualitative import Set1_9
from palettable.tableau import Tableau_10, Tableau_20
from cycler import cycler

# Set some commonly used colors
almost_black = '#262626'
light_grey = np.array([float(248) / float(255)] * 3)

# ColorBrewer
# by Drs. Cynthia Brewer and Mark Harrower of Pennsylvania
# State University. For more information on ColorBrewer, see:
# - Flash-based interactive map:
# http://colorbrewer2.org/
# - A quick visual reference to every ColorBrewer scale:
# http://bl.ocks.org/mbostock/5577023
# https://jiffyclub.github.io/palettable/colorbrewer
#
# ColorBrewer scale 'Qualitative.Set1'.
# This one has nice "traditional" colors like reds and blues
# It is suitable for multi-line plots and category items.
brewer_set1 = Set1_9.mpl_colors
# Remove the sixth color (yellow) which is too bright
brewer_set1.pop(5)
# Swap the red and blue to let blue come first
brewer_set1[0], brewer_set1[1] = brewer_set1[1], brewer_set1[0]
# Add a decent black color to this list
brewer_set1.append(almost_black)

# Tableau 10 & 20 Classic
# See: https://jiffyclub.github.io/palettable/tableau/
# Another great qualitative set of colors suitable for multi-line plots.
# 10 and 20 are number of colors in the list.
tableau_10 = Tableau_10.mpl_colors
# Add a decent black color
tableau_10.append(almost_black)
# Swap orange and red
tableau_10[1], tableau_10[3] = tableau_10[3], tableau_10[1]
# swap orange and purple
# now table_au has similar sequence to brewer_set1
tableau_10[3], tableau_10[4] = tableau_10[4], tableau_10[3]
# This is 20-color Tableau which contains light version of tableau_10
tableau_20 = Tableau_20.mpl_colors

default_color_cycler = cycler('color', tableau_10)



# -*- coding: utf-8 -*-
"""
mpltex
======

**mpltex** is a python package for producing publication quality images using matplotlib.

"""

__author__ = "Yi-Xin Liu <liuyxpp@gmail.com>"
__license__ = "BSD License"

from ._version import __version__

from .general import *
from .colors import *
from .styles import *
from .layout import *
from .acs import *
from .rsc import *
from .aps import *
from .presentation import *
from .web import *



# -*- coding: utf-8 -*-
"""
rsc.py
======

Context decorator for producing figures which is ready to publish
in Royal Society of Chemistry.

Reference:
    RSC Authour Guidelines

EPS format for image file are used, because of its high quality and working
in actual physical size rahter than pixel unit.

"""

from .general import MPLdecorator
from .colors import default_color_cycler
from .layout import GOLDEN_RATIO

__all__ = ['rsc_decorator', ]

# Constants from RSC Authour Guidelines.
width_single_column = 3.26  # 8.3 cm
width_double_column = 6.73  # 17.1 cm

# Default ratio for a single plot figure
# I prefer a little higher than goden ratio, from 0.618 to about 0.68
height_width_ratio = GOLDEN_RATIO * 1.1  # = height / width

_width = width_single_column
_height = width_single_column * height_width_ratio

_params = {'font.family': 'sans-serif',
           'font.serif': ['Times', 'Computer Modern Roman'],
           'font.sans-serif': ['Helvetica', 'Arial',
                               'Computer Modern Sans serif'],
           'font.size': 7,
           'text.usetex': True,
           # To force LaTeX use Helvetica fonts.
           'text.latex.preamble': [r'\usepackage{siunitx}',
                                   r'\sisetup{detect-all}',
                                   r'\usepackage{helvet}',
                                   r'\usepackage[eulergreek,EULERGREEK]{sansmath}',
                                   r'\sansmath'],
           'axes.prop_cycle': default_color_cycler,
           'axes.labelsize': 7,
           'axes.linewidth': 1,

           'figure.figsize': (_width, _height),
           'figure.subplot.left': 0.125,
           'figure.subplot.right': 0.95,
           'figure.subplot.bottom': 0.1,
           'figure.subplot.top': 0.95,

           'savefig.dpi': 300,
           'savefig.format': 'eps',
           # 'savefig.bbox': 'tight',
           # this will crop white spaces around images that will make
           # width/height no longer the same as the specified one.

           'legend.fontsize': 7,
           'legend.frameon': False,
           'legend.numpoints': 1,
           'legend.handlelength': 2,
           'legend.scatterpoints': 1,
           'legend.labelspacing': 0.5,
           'legend.markerscale': 0.9,
           'legend.handletextpad': 0.5,  # pad between handle and text
           'legend.borderaxespad': 0.5,  # pad between legend and axes
           'legend.borderpad': 0.5,  # pad between legend and legend content
           'legend.columnspacing': 1,  # pad between each legend column

           # 'text.fontsize' : 7,  # use font.size for Matplotlib 1.4.2+
           'xtick.labelsize': 7,
           'ytick.labelsize': 7,

           'lines.linewidth': 1,
           'lines.markersize': 4,
           # 'lines.markeredgewidth' : 0,
           # 0 will make line-type markers, such as '+', 'x', invisible
           }

rsc_decorator = MPLdecorator(_params)



# -*- coding: utf-8 -*-
"""
presentation.py
===============

Context decorator for producing figures suitable in presentation for
Mac OS Keynote or Microsoft PowerPoint.

PDF format for image file are used, because it correctly uses sans-serif fonts.

"""

from .general import MPLdecorator
from .layout import point2inch, GOLDEN_RATIO
from .colors import default_color_cycler

__all__ = ['presentation_decorator', ]

# Constants for presentation
_width_full_pt = 1024  # Units in number of points (or dots)
_width_normal_pt = int(_width_full_pt / 3.0)
width_normal = point2inch(_width_normal_pt)
width_tiny = 0.5 * width_normal
width_small = 0.8 * width_normal
width_large = 1.2 * width_normal
width_large2 = 1.5 * width_normal
width_huge = 1.8 * width_normal
width_full = 0.9 * point2inch(_width_full_pt)  # use 90% of presentation page.

# Default ratio for a single plot figure
# I prefer a little higher than goden ratio, from 0.618 to 0.68
height_width_ratio = GOLDEN_RATIO * 1.1  # = height / width

_width = width_normal
_height = _width * height_width_ratio

_params = {'font.family': 'sans-serif',
           'font.serif': ['Times', 'Computer Modern Roman'],
           'font.sans-serif': ['Helvetica', 'Arial', 'Lucida Grande'],
           'font.size': 12,
           'font.weight': 'normal',
           'text.usetex': True,
           # To force LaTeX use Helvetica fonts.
           'text.latex.preamble': [r'\usepackage{siunitx}',
                                   r'\sisetup{detect-all}',
                                   r'\usepackage{helvet}',
                                   r'\usepackage[eulergreek,EULERGREEK]{sansmath}',
                                   r'\sansmath'],
           'axes.prop_cycle': default_color_cycler,
           'axes.labelsize': 'medium',
           'axes.labelweight': 'normal',
           'axes.linewidth': 1.5,

           'figure.figsize': (_width, _height),
           'figure.subplot.left': 0.125,
           'figure.subplot.right': 0.95,
           'figure.subplot.bottom': 0.1,
           'figure.subplot.top': 0.95,

           'savefig.dpi': 300,
           'savefig.format': 'pdf',
           # 'savefig.bbox': 'tight',
           # this will crop white spaces around images that will make
           # width/height no longer the same as the specified one.

           'legend.fontsize': 'small',
           'legend.frameon': False,
           'legend.numpoints': 1,
           'legend.handlelength': 2,
           'legend.scatterpoints': 1,
           'legend.labelspacing': 0.5,
           'legend.markerscale': 0.9,
           'legend.handletextpad': 0.5,  # pad between handle and text
           'legend.borderaxespad': 0.5,  # pad between legend and axes
           'legend.borderpad': 0.5,  # pad between legend and legend content
           'legend.columnspacing': 1,  # pad between each legend column

           # 'text.fontsize': 'medium',

           'xtick.major.size': 6,
           # 'xtick.minor.size' : 2,
           'xtick.major.width': 1.5,
           # 'xtick.minor.width' : 0.5,
           # 'xtick.major.pad' : 4,
           # 'xtick.minor.pad' : 4,
           # 'xtick.color' : k,
           'xtick.labelsize': 'medium',
           # 'xtick.direction' : 'in',

           'ytick.major.size': 6,
           # 'ytick.minor.size' : 2,
           'ytick.major.width': 1.5,
           # 'ytick.minor.width' : 0.5,
           # 'ytick.major.pad' : 4,
           # 'ytick.minor.pad' : 4,
           # 'ytick.color' : k,
           'ytick.labelsize': 'medium',
           # 'ytick.direction' : 'in',

           'lines.linewidth': 1.5,
           'lines.markersize': 6,
           # 'lines.markeredgewidth' : 0,
           # 0 will make line-type markers, such as '+', 'x', invisible
           }

presentation_decorator = MPLdecorator(_params)



# -*- coding: utf-8 -*-
"""
styles.py
=========

Toolkits and constants for plotting styles.

"""

import itertools

from .colors import almost_black, tableau_10

__all__ = ['colors', 'lines',
           'markers', 'markersh', 'marker_types',
           'linestyle_generator', 'linestyles']

_colors = tableau_10
colors = itertools.cycle(_colors)

_lines = ['-', '--', '-.', ':']
lines = itertools.cycle(_lines)

_markers = ['o', 's', 'v', '^', 'D', '<', '>', 'p', 'h']
markers = itertools.cycle(_markers)

# for making hollow markers, use it together with marker_types
_markersh = ['o', 'o', 's', 's', 'v', 'v', '^', '^', 'D', 'D']
markersh = itertools.cycle(_markersh)

_marker_types = [False, True]  # True for hollow markers
marker_types = itertools.cycle(_marker_types)


def linestyles(colors=_colors, lines=_lines,
               markers=_markers, hollow_styles=_marker_types):
    """
    Short name for ``linestyle_generator``.
    To be compatible with previous versions.
    """
    return linestyle_generator(colors, lines, markers, hollow_styles)


def linestyle_generator(colors=_colors, lines=_lines,
                        markers=_markers, hollow_styles=_marker_types):
    """
    Generate a dict for configuring plot line styles.

    The default line style is markers linked by lines, both styles are cycled,
    and hollow markers are included.

    Usage::

      linestyles = linestyle_generator()
      linestyle = next(linestyles)

    Note that all inputs should be iterable objects.
    To exclude one style, just pass empty list or ``None`` to the corresponding argument.
    To include one style but not cycle, just pass a single-element list.
    For example, pass ``lines=['-'] to apply solid line style to all line arts.
    Similarly, passing ``markers=['o']`` will apply filled circle only.

    :param colors: list of colors, (tuple of RGB or #FFFFFF
                or color name string)
    :type colors: list of tuple or list of string or ``None``
    :param lines: list of line styles within ('-', '--', '-.', ':')
    :type lines: list of string,  or ``None``
    :param markers: list of markers (see matplotlib for available markers)
    :type markers: list of charaters,  or ``None``
    :param hollow_styles: True for hollow markers, False for filled markers.
    :param hollow_styles: list of bool,  or ``None``
    :return: dict of parameters of linestyle
    :rtype: dict
    """

    # If both lines and markers are empty or None, do nothing
    is_nothing = False
    if not lines and not markers:
        is_nothing = True

    if colors:
        color_cycle = itertools.cycle(colors)
    else:  # default line color is almost_black
        color_cycle = itertools.cycle([almost_black])

    if lines:
        line_cycle = itertools.cycle(lines)
    else:  # empty list or None supplied, disable line connection
        line_cycle = itertools.cycle([''])

    if markers and hollow_styles:  # solid and hollow markers
        full_markers = itertools.product(markers, hollow_styles)
    elif markers and not hollow_styles:  # all solid markers
        full_markers = itertools.product(markers, [None])
    else:  # no markers
        full_markers = itertools.product(['None'], [None])
    marker_cycle = itertools.cycle(full_markers)

    while True:
        if not is_nothing:
            # Use next() instead of .next to work with both Python 2 & 3
            color = next(color_cycle)
            linestyle = next(line_cycle)
            marker, hollow = next(marker_cycle)
            if hollow is None:  # only filled markers
                mew = 1
                mec = color
                mfc = color
            elif hollow:  # make hollow markers
                mew = 1
                mec = color
                mfc = 'None'
            else:  # otherwise, make filled markers
                mew = 1
                mec = color
                mfc = color
            yield {'color': color, 'linestyle': linestyle,
                   'marker': marker, 'mew': mew, 'mec': mec, 'mfc': mfc}
        else:
            yield {}



"""
setup.py
========

:copyright: (c) 2014 by Yi-Xin Liu
:license: BSD, see LICENSE.txt for more details.
"""

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import os
import sys
cwd = os.path.dirname(os.path.abspath(__file__))

# Read __version__ from _version.py and add it into the current variable space.
exec(open('mpltex/_version.py').read())

setup(
    name='mpltex',
    version=__version__,
    license='BSD',
    description='mpltex is a python package for creating publication-quality plots using matplotlib.',
    author='Yi-Xin Liu',
    author_email='liuyxpp@gmail.com',
    url='https://github.com/liuyxpp/mpltex',
    packages=['mpltex'],
    include_package_data=True,
    zip_safe=False,
    long_description=open(os.path.join(cwd, 'README.rst')).read(),
    install_requires=[
        'matplotlib',
        'palettable',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Scientific/Engineering',
        'Topic :: Education', ],
)
